==> nextcloud-22.2.10.tgz: nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "Load average: {cpu} (last minute)" : "Gemiddelde belasting: {cpu} (laatste minuut)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Users" : "Gebruikers",
    "Groups" : "Groepen",
    "Links" : "Links",
    "Emails" : "E-mails",
    "Federated sent" : "Gefedereerd verstuurd",
    "Federated received" : "Gefedereerd ontvangen",
    "Talk conversations" : "Talk-gesprekken",
    "24 hours" : "24 uur",
    "1 hour" : "1 uur",
    "5 mins" : "5 min",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System:" : "Besturingssysteem:",
    "Unknown Processor" : "Onbekende Processor",
    "Memory:" : "Geheugen:",
    "Uptime:" : "Bedrijfstijd:",
    "Temperature" : "Temperatuur",
    "Load" : "Belasting",
    "Memory" : "Geheugen",
    "Disk" : "Schijf",
    "Filesystem:" : "Bestandssysteem:",
    "Size:" : "Grootte:",
    "Available:" : "Beschikbaar:",
    "Used:" : "Gebruikt:",
    "You will get a notification once one of your disks is nearly full." : "Je krijgt een melding als een van je schijven bijna vol is.",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Speed:" : "Snelheid:",
    "Active users" : "Actieve gebruikers",
    "Total users:" : "Totaal aantal gebruikers:",
    "Shares" : "Shares",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory limit:" : "Geheugen limiet:",
    "Upload max size:" : "Max uploadomvang:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Externe monitoring tool",
    "You can connect an external monitoring tool by using this end point:" : "Je kunt een externe monitor-tool verbinden door dit end point te gebruiken:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wanneer je \"?format=json\" toevoegt aan het einde van de URL ontvang je het resultaat in JSON",
    "To use an access token, please generate one then set it using the following command:" : "Om een ​​toegangstoken te gebruiken, genereert u er een en stelt u deze in met de volgende opdracht:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL.",
    "Load average" : "Gemiddelde belasting",
    "Last minute" : "Laatste minuut",
    "Memory info not available" : "Geheugeninfo niet beschikbaar",
    "Total" : "Totaal",
    "Current usage" : "Huidig gebruik",
    "Mails" : "Mails",
    "Operating System" : "Operating System",
    "CPU" : "CPU",
    "Server time" : "Servertijd",
    "Uptime" : "Uptime",
    "Mount" : "Koppeling",
    "Filesystem" : "Bestandssysteem",
    "Size" : "Grootte",
    "Available" : "Beschikbaar",
    "Used" : "Gebruikt",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Snelheid",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Memory Limit:" : "Geheugenlimiet:",
    "Max Execution Time:" : "Max verwerkingstijd:",
    "To use an access token please generate one then set it using the following command:" : "Om een toegangstoken te gebruiken, genereer er a.u.b een en stel deze in via het volgende commando:",
    "Files" : "Bestanden",
    "Storages" : "Opslag",
    "Free Space" : "Vrije Ruimte",
    "Total users" : "Totaal aantal gebruikers",
    "Version" : "Versie",
    "Memory limit" : "Geheugenlimiet",
    "Max execution time" : "Maximale uitvoeringstijd",
    "Upload max size" : "Maximale upload-grootte",
    "Type" : "Type",
    "You can connect an external monitoring tool by using this end point" : "Je kunt een externe monitoringtool aansluiten door deze end point te gebruiken",
    "To use an access token, please generate one then set it using the following command" : "Om een toegangstoken te gebruiken, genereer er a.u.b een en stel deze in via het volgende commando"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.3.tgz: nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "Load average: {cpu} (last minute)" : "Gemiddelde belasting: {cpu} (laatste minuut)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Users" : "Gebruikers",
    "Groups" : "Groepen",
    "Links" : "Links",
    "Emails" : "E-mails",
    "Federated sent" : "Gefedereerd verstuurd",
    "Federated received" : "Gefedereerd ontvangen",
    "Talk conversations" : "Talk-gesprekken",
    "24 hours" : "24 uur",
    "1 hour" : "1 uur",
    "5 mins" : "5 min",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System" : "Operating System",
    "CPU" : "CPU",
    "Unknown Processor" : "Onbekende Processor",
    "Memory" : "Geheugen",
    "Server time" : "Servertijd",
    "Uptime" : "Uptime",
    "Load" : "Belasting",
    "Disk" : "Schijf",
    "Mount" : "Koppeling",
    "Filesystem" : "Bestandssysteem",
    "Size" : "Grootte",
    "Available" : "Beschikbaar",
    "Used" : "Gebruikt",
    "You will get a notification once one of your disks is nearly full." : "Je krijgt een melding als een van je schijven bijna vol is.",
    "Files" : "Bestanden",
    "Storages" : "Oplsag",
    "Free Space" : "Vrije Ruimte",
    "Network" : "Netwerk",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Snelheid",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Actieve gebruikers",
    "Total users" : "Totaal aantal gebruikers",
    "Shares" : "Shares",
    "PHP" : "PHP",
    "Version" : "Versie",
    "Memory limit" : "Geheugenlimiet",
    "Max execution time" : "Maximale uitvoeringstijd",
    "Upload max size" : "Maximale upload-grootte",
    "Database" : "Database",
    "Type" : "Type",
    "External monitoring tool" : "Externe monitoring tool",
    "You can connect an external monitoring tool by using this end point" : "Je kunt een externe monitoringtool aansluiten door deze end point te gebruiken",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wanneer je \"?format=json\" toevoegt aan het einde van de URL ontvang je het resultaat in JSON",
    "To use an access token, please generate one then set it using the following command" : "Om een toegangstoken te gebruiken, genereer er a.u.b een en stel deze in via het volgende commando",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL.",
    "Load average" : "Gemiddelde belasting",
    "Last minute" : "Laatste minuut",
    "Memory info not available" : "Geheugeninfo niet beschikbaar",
    "Total" : "Totaal",
    "Current usage" : "Huidig gebruik",
    "Mails" : "Mails",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Total users:" : "Totaal aantal gebruikers:",
    "Version:" : "Versie:",
    "Memory Limit:" : "Geheugenlimiet:",
    "Max Execution Time:" : "Max verwerkingstijd:",
    "Upload max size:" : "Max uploadomvang:",
    "Type:" : "Type:",
    "Size:" : "Grootte:",
    "You can connect an external monitoring tool by using this end point:" : "Je kunt een externe monitor-tool verbinden door dit end point te gebruiken:"
},
"nplurals=2; plural=(n != 1);");
